@@ -2004,6 +2004,34 @@ class OcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def VerifyOfdVatInvoiceOCR(self, request):
+        """本接口支持OFD格式的增值税电子普通发票和增值税电子专用发票的识别，返回发票代码、发票号码、开票日期、验证码、机器编号、密码区，购买方和销售方信息，包括名称、纳税人识别号、地址电话、开户行及账号，以及价税合计、开票人、收款人、复核人、税额、不含税金额等字段信息。
+
+        :param request: Request instance for VerifyOfdVatInvoiceOCR.
+        :type request: :class:`tencentcloud.ocr.v20181119.models.VerifyOfdVatInvoiceOCRRequest`
+        :rtype: :class:`tencentcloud.ocr.v20181119.models.VerifyOfdVatInvoiceOCRResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("VerifyOfdVatInvoiceOCR", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.VerifyOfdVatInvoiceOCRResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def VinOCR(self, request):
         """本接口支持图片内车辆识别代号（VIN）的检测和识别。
 
